import {
  injectProviders,
  rpcProviderWarning,
  selectProviders
} from "./chunk-IGSCEOZ3.js";

// src/hooks/common/promptAndInjectEtherscan.ts
import fs from "fs-extra";
import { default as prompts } from "prompts";
import path from "path";
var promptAndInjectEtherscan = () => ({
  async afterValidate({ context }) {
    const errorMessage = "Etherscan API Key is required.";
    const etherscanApiKey = (await prompts({
      name: "etherscanApiKey",
      message: "What is your Etherscan API Key?",
      type: "text",
      validate(projectId) {
        if (!projectId)
          return errorMessage;
        return true;
      }
    })).etherscanApiKey;
    context.set({ etherscanApiKey });
  },
  async beforeInstall({ context, targetPath }) {
    const { etherscanApiKey } = context.get();
    if (!etherscanApiKey)
      return;
    if (!fs.existsSync(path.join(targetPath, ".env")))
      fs.writeFileSync(path.join(targetPath, ".env"), "");
    fs.appendFileSync(
      path.join(targetPath, ".env"),
      `ETHERSCAN_API_KEY=${etherscanApiKey}
`
    );
  }
});

// src/hooks/common/promptAndInjectProjectId.ts
import fs2 from "fs-extra";
import pico from "picocolors";
import { default as prompts2 } from "prompts";
import path2 from "path";
var log = console.log;
var promptAndInjectProjectId = () => ({
  async afterValidate({ context }) {
    const walletConnectProjectId = (await prompts2({
      name: "walletConnectProjectId",
      message: `Optional: What is your WalletConnect Cloud Project ID?
${pico.blue(
        "Find it at: https://cloud.walletconnect.com/sign-in"
      )}
${pico.cyan("\u23CE to skip")}
`,
      type: "text"
    })).walletConnectProjectId;
    context.set({ walletConnectProjectId });
  },
  async beforeInstall({ context, targetPath }) {
    const { walletConnectProjectId } = context.get();
    const configPath = path2.join(targetPath, "src", "wagmi.ts");
    const config = fs2.readFileSync(configPath).toString();
    if (!walletConnectProjectId) {
      fs2.writeFileSync(
        configPath,
        config.replace(
          "\nconst walletConnectProjectId = '<WALLET_CONNECT_PROJECT_ID>'\n",
          ""
        ).replace(
          /(new WalletConnectConnector(.|\n)*}\),)\n\s\s\s\s*(.*new)/,
          "$3"
        )
      );
      return;
    }
    fs2.writeFileSync(
      configPath,
      config.replace("<WALLET_CONNECT_PROJECT_ID>", walletConnectProjectId)
    );
    log(pico.green("\u2714"), "Added WalletConnect Project ID.");
    log();
  }
});

// src/hooks/common/selectAndInjectProviders.ts
var selectAndInjectProviders = ({
  envNamespace,
  envPrefix
}) => ({
  async afterValidate({ context }) {
    const { envVars, providerNames } = await selectProviders();
    context.set({ envVars, providerNames });
  },
  async beforeInstall({ context, targetPath }) {
    const { envVars, providerNames } = context.get();
    injectProviders({
      envNamespace,
      envPrefix,
      envVars,
      providerNames,
      targetPath
    });
  },
  async afterSetup({ context }) {
    const { providerNames } = context.get();
    if (providerNames.length === 1 && providerNames[0] === "public") {
      rpcProviderWarning();
    }
  }
});

export {
  promptAndInjectEtherscan,
  promptAndInjectProjectId,
  selectAndInjectProviders
};
